/*************************************************************************************************************************
									File Details
**************************************************************************************************************************
	File name 						: main.C
	
	Purpose							: This file has the main function to program an ldr to the parallel FLASH
	
	Author							: Mitesh Moonat & Harshit Gaharwar
	
	VDSP version used for testing	: VisualDSP++ 5.0, Update 10
	
	Hardware used					: ADSP-21469, ADSP-21479, ADSP-21489, ADSP-21375, ADSP-21369 EZ-Kits 
									  and ADSP-21469, ADPS-21367, ADSP-21375 BUBs
	
	Connection details 				: Make sure that the switch/jumper connecting the /MS1 of the DSP to the FLASH
									  chip select is ON. In case of socketed FLASH, make sure that the FLASH is placed
									  in socket.In case of custom board, make sure that DSP-FLASH signals are connected.
	Guidelines for change			: 1) No changes required for a different processor. 
	
	
									  2) For a different FLASH device, change the line:
									  
									  	 "g_parallel_flash_device_info.CommandSet.bWordAsByte=true;"
									  
									  	  to true of false depending upon whether the FLASH device is a 16 bit device used 
									 	  in byte mode (=true) or is a 8 bit device only (=false).
									 	  
									 	  
									  3)  For a different boot image (ldr file): 
									  
									  	  - Change the file name corresponding to "ldr_buff" if the programming is to be 
									  	  	done using memory storage.The file should be generated in ASCII format WITH 
									  	  	commas in between each byte.
									  	  	
									  	  - Change the file name corresponding to  "LDR_PATH" if the programming is to be 
									  	    done using FILE I/O. The file should be generated in ASCII format WITHOUT  
									  	    commas in between each byte.
										  
**************************************************************************************************************************/
/*************************************************************************************************************************
									Include Files
*************************************************************************************************************************/
#include "main.h"


/*************************************************************************************************************************
									Global Variables
**************************************************************************************************************************/

//If the ldr is stored completely inside interal/external memory - Preferred method as it is FASTER
#ifdef USE_MEMORY_STORAGE_FOR_LDR_PROGRAMMING

	//If the ldr is stored completely inside external memory - SLOWER- need to be used only when the internal memory is
	//not enough to store the ldr file		
	#ifdef USE_EXTENAL_MEMORY_FOR_LDR_STORAGE
		#pragma section("seg_ext_data")
	#endif

	//Statically initialize the ldr buffer with the ldr file contents
	unsigned char ldr_buff[]= {
									#include "Blink1_Include_8bit.ldr"	//Change the ldr file name here
	};

#endif

	
/*************************************************************************************************************************
									Main Function
*************************************************************************************************************************/
int main( void )
{

	//Local variables
	int iTemp=0;
	int halt=0;
	
	#ifdef USE_FILE_IO_FOR_LDR_PROGRAMMING
		//Change the path here in case of FILE I/O method
		char LDR_PATH[200]="C:/Ldr Files/Parallel/Blink1_21469_ASCII_8bit.ldr";
	#endif
	
	//Initialize PLL - programs CCLK, DDR2CLK/SDCLK
	Init_PLL();
	
	#ifdef USE_EXTENAL_MEMORY_FOR_LDR_STORAGE
		//Initialize SDRAM/DDR2 controller
		Init_DRAM();
	#endif
	
	//Initialize EPCTL and AMICTL registers
	Setup_System_For_FLASH();
	
	//Specify whether the FLASH being used is a 16 bit used in byte mode or 8 bit device 
	g_parallel_flash_device_info.CommandSet.bWordAsByte=true;
	
	//Auto Select the FLASH device by reading manufaturer and device ID and initialize various FLASH specific information
	//such as device size, sector address map, command set etc.
	Parallel_FLASH_Collect_Device_Info(&g_parallel_flash_device_info);
	
	//Print the FLASH deivce information collected in the above step
	Parallel_FLASH_Print_Device_Info(&g_parallel_flash_device_info);
	
	//If "Memory Storage" method used for FLASH programming
	#ifdef USE_MEMORY_STORAGE_FOR_LDR_PROGRAMMING

		//Program the ldr file contents here in to the FLASH
		iTemp=Program_LDR_File_to_Parallel_FLASH_From_Memory(ldr_buff, sizeof(ldr_buff), 0, &g_parallel_flash_device_info);
	
	#endif
	
	//If "FILE I/O" method used for FLASH programming
	#ifdef USE_FILE_IO_FOR_LDR_PROGRAMMING
		
		//Program the ldr file contents here in to the FLASH
		iTemp=Program_LDR_File_to_Parallel_FLASH(LDR_PATH, 0, &g_parallel_flash_device_info);
		
	#endif
	
	//Print the status of the FLASH programming here - 2137x having less internal memory, printf can't be used
	#if !defined(__2137x__)
		if(iTemp==1)
			printf("\nLDR file programmed successfully!\n");
		else
			printf("\nError programming the LDR file!\n");
	#endif
	
	//Infinite loop at the end, put the breakpoint here.
	while(!halt)
	{
		iTemp++;
	}
}


/**************************************** END OF FILE*********************************************************************/
